@@ -31,4 +31,6 @@ def extract_data() -> Callable[
 def extract_http_data() -> Callable[
     [Observable[HttpResponse]], Observable[list | dict]
 ]:
-    return operators.map(lambda x: x["data"])
+    return operators.map(lambda x: (
+        x["data"]
+    ))
